import * as React from 'react';
import React__default from 'react';
import { DataTableConfig, TableApi } from '@procore/data-table';
import * as styled_components from 'styled-components';
import * as _procore_core_react_dist_Section from '@procore/core-react/dist/Section';
import * as _procore_core_react_dist_Panel_Panel_types from '@procore/core-react/dist/Panel/Panel.types';
import * as _procore_core_react from '@procore/core-react';
import { FormikHelpers } from 'formik';

interface ISavedView {
    id: string;
    name: string;
    description: string;
    filters: {
        [key: string]: unknown;
    } | undefined;
    rowHeight: number;
    created_at: string;
    updated_at: string;
    columnState: DataTableConfig['columnState'];
}

type AllItemsOptionProps = {
    selectedId?: string | null;
    onSelect: (data: {
        item: ISavedView;
    }) => void;
};
declare const AllItemsOption: React__default.ForwardRefExoticComponent<AllItemsOptionProps & React__default.RefAttributes<HTMLDivElement>>;

declare const ExpandedPanel: styled_components.StyledComponent<React__default.ForwardRefExoticComponent<_procore_core_react.PanelProps & React__default.RefAttributes<HTMLDivElement>> & {
    Body: React__default.ForwardRefExoticComponent<_procore_core_react.PanelBodyProps & React__default.RefAttributes<HTMLDivElement>>;
    Footer: React__default.ForwardRefExoticComponent<_procore_core_react.DivAttributes & React__default.RefAttributes<HTMLDivElement>>;
    FooterActions: React__default.ForwardRefExoticComponent<_procore_core_react.DivAttributes & React__default.RefAttributes<HTMLDivElement>>;
    FooterNotation: React__default.ForwardRefExoticComponent<_procore_core_react.DivAttributes & React__default.RefAttributes<HTMLDivElement>>;
    Header: React__default.ForwardRefExoticComponent<_procore_core_react.PanelHeaderProps & React__default.RefAttributes<HTMLDivElement>>;
    HeaderAction: React__default.ForwardRefExoticComponent<_procore_core_react.PanelHeaderActionProps & React__default.RefAttributes<HTMLSpanElement>>;
    HeaderActions: React__default.ForwardRefExoticComponent<_procore_core_react.DivAttributes & {
        qa?: Pick<_procore_core_react_dist_Panel_Panel_types.PanelQaTags, "moreIcon"> | undefined;
    } & React__default.RefAttributes<HTMLDivElement>>;
    Section: React__default.ForwardRefExoticComponent<_procore_core_react_dist_Section.SectionProps & React__default.RefAttributes<HTMLDivElement>>;
    Title: React__default.ForwardRefExoticComponent<_procore_core_react.TypographyProps & {
        qa?: Pick<_procore_core_react_dist_Panel_Panel_types.PanelQaTags, "title"> | undefined;
        id?: string | undefined;
    } & React__default.RefAttributes<HTMLSpanElement>>;
}, any, {}, never>;
interface ISavedViews {
    isAdmin: boolean;
    savedViewsGroups: ISavedView[];
    AllItemsOptionFlag?: boolean;
    selectedSavedView?: ISavedView;
    onCreate: (data: {
        name: string;
        description: string;
    }) => void;
    onDelete: (id: ISavedView['id']) => void;
    onSelect: (data: {
        item: ISavedView;
    }) => void;
    onEdit: (data: {
        name: string;
        description: string;
    }) => void;
    onUpdate: (data: {
        savedView: ISavedView;
    }) => void;
}
type PanelContentProps = {
    isAdmin: boolean;
    savedViewsGroups: ISavedView[];
    AllItemsOptionFlag?: boolean;
    selectedSavedViewId?: ISavedView['id'];
    onEdit: (type: 'create' | 'update') => void;
    onDelete: () => void;
    onSelect: (data: {
        item: ISavedView;
    }) => void;
    onUpdate: (data: {
        savedView: ISavedView;
    }) => void;
};
declare const PanelContent: (props: PanelContentProps) => React__default.JSX.Element;
declare const SavedViews: (props: ISavedViews) => React__default.JSX.Element;

type SavedViewCollectionMenuItemProps = {
    item: ISavedView;
    displayName: string;
    selected: boolean;
    onSelect: (data: {
        item: ISavedView;
    }) => void;
    onUpdate?: (data: {
        savedView: ISavedView;
    }) => void;
    onDelete?: (data: {
        savedView: ISavedView;
    }) => void;
    onEdit?: (data: {
        savedView: ISavedView;
    }) => void;
    renderUpdateButton?: boolean;
    renderOverflowMenu?: boolean;
    updateButtonDisabled?: boolean;
    updateButtonTooltip?: string;
    isUpdateProcessing?: boolean;
    allActionsDisabled?: boolean;
};
declare const SavedViewCollectionMenuItem: React.FC<SavedViewCollectionMenuItemProps>;

type OnEditSave = (savedViewFormFields: {
    name: string;
    description: string;
}, formikHelpers: FormikHelpers<{
    name: string;
    description: string;
}>) => void;
type OnCreateSave = (savedViewFormFields: {
    name: string;
    description: string;
}, formikHelpers: FormikHelpers<{
    name: string;
    description: string;
}>) => void;
type SavedViewsCollectionsModalProps = {
    open: boolean;
    isLoading?: boolean;
    onEditSave: OnEditSave;
    onCreateSave: OnCreateSave;
    onCancel(): void;
    type: 'create' | 'update';
    initialName: string;
    initialDesc: string;
};
declare const SavedViewsCollectionsModal: React.FC<SavedViewsCollectionsModalProps>;

type Props = {
    onDelete(): void;
    onCancel(): void;
    name: string;
    open: boolean;
};
declare const SavedViewsDeleteConfirmationModalShared: React__default.FC<Props>;

type UseSavedViewsProps = {
    savedViewsGroups: ISavedView[];
    stickyViewsKey: string;
    tableApi: TableApi;
    tableConfig: DataTableConfig;
    onTableConfigChange: (data: DataTableConfig) => void;
    currentFilters: DataTableConfig['filters'];
    currentColumnState: DataTableConfig['columnState'];
    currentRowHeight: number;
    onUpdate?: (data: ISavedView) => void;
    onDelete?: (id: string) => void;
    onEdit?: (data: {
        id: string;
        name: string;
        description: string;
    }) => void;
    onCreate?: (data: ISavedView) => void;
    onSelect?: () => void;
    isAdmin: boolean;
    AllItemsOptionFlag?: boolean;
};
declare const useSavedViews: (props: UseSavedViewsProps) => {
    SavedViews: () => React__default.JSX.Element;
    selectedSavedView: ISavedView;
};

declare const savedViews: ISavedView[];

declare const saveToStorage: (key: string, data: unknown) => void;
declare const getFromStorage: (key: string) => unknown;

export { AllItemsOption, ExpandedPanel, ISavedViews, OnCreateSave, OnEditSave, PanelContent, SavedViewCollectionMenuItem, SavedViews, SavedViewsCollectionsModal, SavedViewsDeleteConfirmationModalShared, UseSavedViewsProps, getFromStorage, saveToStorage, savedViews, useSavedViews };
